==> grommet-2.7.1.tgz: package/components/CheckBox/stories/Basics.js <==
"use strict";

var _react = _interopRequireWildcard(require("react"));

var _react2 = require("@storybook/react");

var _grommet = require("grommet");

var _themes = require("grommet/themes");

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var SimpleCheckBox =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(SimpleCheckBox, _Component);

  function SimpleCheckBox(props) {
    var _this;

    _this = _Component.call(this, props) || this;

    _defineProperty(_assertThisInitialized(_this), "onChange", function (event) {
      return _this.setState({
        checked: event.target.checked
      });
    });

    _this.state = {
      checked: !!props.checked
    };
    return _this;
  }

  var _proto = SimpleCheckBox.prototype;

  _proto.render = function render() {
    var checked = this.state.checked;
    return _react.default.createElement(_grommet.Grommet, {
      theme: _themes.grommet
    }, _react.default.createElement(_grommet.Box, {
      align: "center",
      pad: "large"
    }, _react.default.createElement(_grommet.CheckBox, _extends({}, this.props, {
      checked: checked,
      onChange: this.onChange
    }))));
  };

  return SimpleCheckBox;
}(_react.Component);

(0, _react2.storiesOf)('CheckBox', module).add('Simple', function () {
  return _react.default.createElement(SimpleCheckBox, {
    label: "Choice"
  });
}).add('Toggle', function () {
  return _react.default.createElement(SimpleCheckBox, {
    label: "Choice",
    toggle: true
  });
}).add('Disabled', function () {
  return _react.default.createElement(SimpleCheckBox, {
    label: "Choice",
    checked: true,
    disabled: true
  });
}).add('Reverse', function () {
  return _react.default.createElement(SimpleCheckBox, {
    label: "Choice",
    reverse: true
  });
}).add('No Label', function () {
  return _react.default.createElement(SimpleCheckBox, null);
});

==> grommet-2.7.2.tgz: package/components/CheckBox/stories/Basics.js <==
"use strict";

var _react = _interopRequireWildcard(require("react"));

var _react2 = require("@storybook/react");

var _grommet = require("grommet");

var _themes = require("grommet/themes");

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj["default"] = obj; return newObj; } }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var SimpleCheckBox =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(SimpleCheckBox, _Component);

  function SimpleCheckBox(props) {
    var _this;

    _this = _Component.call(this, props) || this;

    _defineProperty(_assertThisInitialized(_this), "onChange", function (event) {
      return _this.setState({
        checked: event.target.checked
      });
    });

    _this.state = {
      checked: !!props.checked
    };
    return _this;
  }

  var _proto = SimpleCheckBox.prototype;

  _proto.render = function render() {
    var checked = this.state.checked;
    return _react["default"].createElement(_grommet.Grommet, {
      theme: _themes.grommet
    }, _react["default"].createElement(_grommet.Box, {
      align: "center",
      pad: "large"
    }, _react["default"].createElement(_grommet.CheckBox, _extends({}, this.props, {
      checked: checked,
      onChange: this.onChange
    }))));
  };

  return SimpleCheckBox;
}(_react.Component);

(0, _react2.storiesOf)('CheckBox', module).add('Simple', function () {
  return _react["default"].createElement(SimpleCheckBox, {
    label: "Choice"
  });
}).add('Toggle', function () {
  return _react["default"].createElement(SimpleCheckBox, {
    label: "Choice",
    toggle: true
  });
}).add('Disabled', function () {
  return _react["default"].createElement(SimpleCheckBox, {
    label: "Choice",
    checked: true,
    disabled: true
  });
}).add('Reverse', function () {
  return _react["default"].createElement(SimpleCheckBox, {
    label: "Choice",
    reverse: true
  });
}).add('No Label', function () {
  return _react["default"].createElement(SimpleCheckBox, null);
});
